# Generated by Django 4.1.7 on 2023-05-03 19:28

from django.db import migrations
import jutil.modelfields


class Migration(migrations.Migration):
    dependencies = [
        ("jacc", "0028_alter_invoice_amount_alter_invoice_overpaid_amount_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="account",
            name="currency",
            field=jutil.modelfields.SafeCharField(blank=True, default="EUR", max_length=3, verbose_name="currency"),
        ),
    ]
