# Generated by Django 4.0.4 on 2022-05-05 22:22

from decimal import Decimal
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("jacc", "0027_alter_invoice_paid_amount"),
    ]

    operations = [
        migrations.AlterField(
            model_name="invoice",
            name="amount",
            field=models.DecimalField(
                blank=True, decimal_places=2, default=Decimal("0.00"), help_text="invoice.amount.help_text", max_digits=10, verbose_name="amount"
            ),
        ),
        migrations.AlterField(
            model_name="invoice",
            name="overpaid_amount",
            field=models.DecimalField(
                blank=True,
                db_index=True,
                decimal_places=2,
                default=Decimal("0.00"),
                editable=False,
                help_text="invoice.overpaid_amount.help_text",
                max_digits=10,
                null=True,
                verbose_name="overpaid amount",
            ),
        ),
        migrations.AlterField(
            model_name="invoice",
            name="paid_amount",
            field=models.DecimalField(
                blank=True,
                db_index=True,
                decimal_places=2,
                default=Decimal("0.00"),
                help_text="invoice.paid_amount.help_text",
                max_digits=10,
                null=True,
                verbose_name="paid amount",
            ),
        ),
        migrations.AlterField(
            model_name="invoice",
            name="unpaid_amount",
            field=models.DecimalField(
                blank=True,
                db_index=True,
                decimal_places=2,
                default=None,
                editable=False,
                help_text="invoice.unpaid_amount.help_text",
                max_digits=10,
                null=True,
                verbose_name="unpaid amount",
            ),
        ),
    ]
