# Generated by Django 4.1.7 on 2023-06-08 14:08

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("jacc", "0029_alter_account_currency"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="accountentry",
            index=models.Index(fields=["account", "created"], name="jacc_accoun_account_f79b79_idx"),
        ),
    ]
