# Generated by Django 3.2 on 2021-04-24 00:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("jacc", "0023_accountentrynote"),
    ]

    operations = [
        migrations.AddField(
            model_name="account",
            name="notes",
            field=models.TextField(blank=True, default="", verbose_name="notes"),
        ),
    ]
