{% extends "admin/base.html" %}
{% load i18n %}

{% block content %}
    <form action="" method="post">
        {% csrf_token %}

    <ul>
        <li>{% trans 'timestamp' %}: {{ original.timestamp }}</li>
        <li>{% trans 'amount' %}: {{ original.amount }} {{ original.account.currency }}</li>
        <li>{% trans 'description' %}: {{ original.description }}</li>
    </ul>

    <table class="reverse-entry-form-table">
        {{ form.as_table }}
    </table>

    <input type="submit" name="save" value="{% trans 'Save' %}"/>

    {% for obj in qs %}
        <input type="hidden" name="_selected_action" value="{{ obj.pk }}" />
    {% endfor %}
    <input type="hidden" name="action" value="add_reverse_charge" />
    </form>
{% endblock %}
